Module core

Module core 

Core structs, enums, and functions

Modules

account_summary_tags
Account summary tags
algo_params
Utility functions that illustrate setting fields related to algo parameters
client
EClient and supporting structs. Responsible for connecting to Trader Workstation or IB Gatway and sending requests
common
Common types
contract
Types related to Contracts
decoder
Receives messages from Reader, decodes messages, and feeds them to Wrapper
errors
Error types
execution
Types related to executions
messages
Functions for processing messages
order
Types related to orders
order_condition
Types related to order and execution conditions
order_decoder
Helper types and functions related to decoding order type messages
reader
Reads and processes messages from the TCP socket
scanner
Types for dealing with scanner data and scanner subscriptions
server_versions
The known server versions.
streamer
wrapper
Clients implement the Wrapper trait in this module to receive data and notifications from Trader WorkStation or IB Gateway