Core structs, enums, and functions
Modules
- account_
summary_ tags - Account summary tags
- algo_
params - Utility functions that illustrate setting fields related to algo parameters
- client
- EClient and supporting structs. Responsible for connecting to Trader Workstation or IB Gatway and sending requests
- common
- Common types
- contract
- Types related to Contracts
- decoder
- Receives messages from Reader, decodes messages, and feeds them to Wrapper
- errors
- Error types
- execution
- Types related to executions
- messages
- Functions for processing messages
- order
- Types related to orders
- order_
condition - Types related to order and execution conditions
- order_
decoder - Helper types and functions related to decoding order type messages
- reader
- Reads and processes messages from the TCP socket
- scanner
- Types for dealing with scanner data and scanner subscriptions
- server_
versions - The known server versions.
- streamer
- wrapper
- Clients implement the Wrapper trait in this module to receive data and notifications from Trader WorkStation or IB Gateway